@@ -20,7 +20,7 @@ BookmarksDialog::BookmarksDialog(Book *book_, QWidget *parent):
     list = new QListWidget(this);
     list->setSelectionMode(QAbstractItemView::SingleSelection);
     foreach (Book::Bookmark bookmark, book_->bookmarks()) {
-        QString contentId = book_->toc[bookmark.chapter];
+        QString contentId = book_->parts[bookmark.part];
         QString contentTitle = book_->content[contentId].name;
         (void)new QListWidgetItem(QIcon(":icons/bookmark.png"), contentTitle +
             "\nAt " + QString::number((int)(bookmark.pos*100)) + "%", list);
