@@ -6,6 +6,7 @@
 #include <QDirIterator>
 #include <QFileInfo>
 #include <QtAlgorithms>
+#include <QCryptographicHash>
 
 #include "book.h"
 #include "opshandler.h"
@@ -19,6 +20,13 @@
 const int COVER_WIDTH = 53;
 const int COVER_HEIGHT = 59;
 
+static QImage makeCover(const QString &path)
+{
+    return QImage(path).scaled(COVER_WIDTH, COVER_HEIGHT,
+        Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation).
+        scaled(COVER_WIDTH, COVER_HEIGHT, Qt::KeepAspectRatio);
+}
+
 Book::Book(const QString &p, QObject *parent): QObject(parent)
 {
     mPath = "";
@@ -26,9 +34,8 @@ Book::Book(const QString &p, QObject *parent): QObject(parent)
         QFileInfo info(p);
         mPath = info.absoluteFilePath();
         title = info.baseName();
-        cover = QImage(":/icons/book.png").scaled(COVER_WIDTH, COVER_HEIGHT,
-            Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation).
-            scaled(COVER_WIDTH, COVER_HEIGHT, Qt::KeepAspectRatio);
+        cover = makeCover(":/icons/book.png");
+        mTempFile.open();
     }
 }
 
@@ -58,6 +65,26 @@ bool Book::open()
     return true;
 }
 
+void Book::peek()
+{
+    Trace t("Book::peek");
+    t.trace(path());
+    close();
+    clear();
+    if (path().isEmpty()) {
+        title = "No book";
+        return;
+    }
+    if (!extractMetaData()) {
+        return;
+    }
+    if (!parse()) {
+        return;
+    }
+    save();
+    close();
+}
+
 void Book::close()
 {
     Trace t("Book::close");
@@ -69,7 +96,8 @@ void Book::close()
 
 QString Book::tmpDir() const
 {
-    return QDir::tempPath() + "/dorian/book";
+    QString tmpName = QFileInfo(mTempFile.fileName()).fileName();
+    return QDir::tempPath() + "/dorian/" + tmpName;
 }
 
 bool Book::extract()
@@ -146,9 +174,7 @@ bool Book::parse()
     foreach (QString key, coverKeys) {
         if (content.contains(key)) {
             t.trace("Loading cover image from " + content[key].href);
-            cover = QImage(content[key].href).scaled(COVER_WIDTH, COVER_HEIGHT,
-                Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation).
-                scaled(COVER_WIDTH, COVER_HEIGHT, Qt::KeepAspectRatio);
+            cover = makeCover(content[key].href);
             break;
         }
     }
@@ -248,9 +274,7 @@ void Book::load()
     cover = settings.value(key + "cover").value<QImage>().scaled(COVER_WIDTH,
         COVER_HEIGHT, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
     if (cover.isNull()) {
-        cover = QImage(":/icons/book.png").scaled(COVER_WIDTH, COVER_HEIGHT,
-            Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation).
-            scaled(COVER_WIDTH, COVER_HEIGHT, Qt::KeepAspectRatio);
+        cover = makeCover(":/icons/book.png");
     }
 
     // Load bookmarks
@@ -440,3 +464,9 @@ qreal Book::getProgress(int part, qreal position)
     partSize += content[key].size * position;
     return partSize / (qreal)size;
 }
+
+bool Book::extractMetaData()
+{
+    // FIXME
+    return extract();
+}
